==> syncthingtray-0.10.2.tar.gz: syncthingtray-0.10.2/model/translations/syncthingmodel_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="193"/>
        <source>Misc. notifications</source>
        <translation>Různá oznámení</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="194"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="195"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="196"/>
        <source>Idle</source>
        <translation>Nečinné</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="197"/>
        <source>Scanning</source>
        <translation>Skenuje</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="198"/>
        <source>Synchronizing</source>
        <translation>Synchronizuje</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="199"/>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="200"/>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="84"/>
        <location filename="../syncthingdevicemodel.cpp" line="114"/>
        <source>ID</source>
        <translation>Identifikátor</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="86"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="116"/>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="118"/>
        <source>Last seen</source>
        <translation>Naposledy spatřeno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="120"/>
        <source>Compression</source>
        <translation>Komprese</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="122"/>
        <source>Certificate</source>
        <translation>Certifikát</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="124"/>
        <source>Introducer</source>
        <translation>Zavaděč</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="126"/>
        <source>Incoming traffic</source>
        <translation>Příchozí provoz</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="128"/>
        <source>Outgoing traffic</source>
        <translation>Odchozí provoz</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="130"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="150"/>
        <source>unknown or own device</source>
        <translation>neznámé nebo vlastní zařízení</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="155"/>
        <source>none</source>
        <translation>žádné</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>yes</source>
        <translation>ano</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="361"/>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="365"/>
        <source>Unknown status</source>
        <translation>Neznámý stav</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="367"/>
        <source>Own device</source>
        <translation>Vlastní zařízení</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="369"/>
        <source>Idle</source>
        <translation>Nečinné</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="371"/>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="373"/>
        <source>Synchronizing (%1 %)</source>
        <translation>Synchronizuje se (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="373"/>
        <source>Synchronizing</source>
        <translation>Synchronizuje se</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="375"/>
        <source>Out of sync</source>
        <translation>Nesesynchronizováno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="377"/>
        <source>Rejected</source>
        <translation>Odmítnuto</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
        <source>ID</source>
        <translation>Identifikátor</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
        <source>Path</source>
        <translation>Popis umístění</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Rescan interval</source>
        <translation>Interval skenování</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Last scan</source>
        <translation>Poslední sken</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Last file</source>
        <translation>Poslední soubor</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Errors</source>
        <translation>Chyby</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
        <source>not shared</source>
        <translation>nesdíleno</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
        <source>unknown</source>
        <translation>neznámé</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 and %2 item(s) out of sync</source>
        <translation>
            <numerusform>%1 a %2 položka nesesynchronizována</numerusform>
            <numerusform>%1 a %2 položky nesesynchronizovány</numerusform>
            <numerusform>%1 a %2 položek nesesynchronizováno</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <source>none</source>
        <translation>žádno</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <source>%1 item(s) out of sync</source>
        <translation>
            <numerusform>%1 položka nesesynchronizována</numerusform>
            <numerusform>%1 položky nesesyncrhonizovány</numerusform>
            <numerusform>%1 položek nesesyncrhonizováno</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="262"/>
        <source>Deleted at %1</source>
        <translation>Smazáno na %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="265"/>
        <source>Updated at %1</source>
        <translation>Aktualizováno na %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="278"/>
        <source>Click for details</source>
        <translation>Pro podrobnosti klikněte</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="277"/>
        <source>Failed items</source>
        <translation>Nezdařené položky</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="460"/>
        <source>Unknown status</source>
        <translation>Neznámý stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
        <source>Idle</source>
        <translation>Nečinné</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="456"/>
        <source>Unshared</source>
        <translation>Nesdíleno</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>Global status</source>
        <translation>Globální stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Local status</source>
        <translation>Místní stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Shared with</source>
        <translation>Sdíleno s</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="464"/>
        <source>Waiting to scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
        <source>Scanning (%1 %, %2)</source>
        <translation>Skenování (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
        <source>Scanning (%1 %)</source>
        <translation>Skenování (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="472"/>
        <source>Scanning</source>
        <translation>Skenování</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
        <source>Preparing to sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
        <source>Synchronizing (%1 %)</source>
        <translation>Synchronizace (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
        <source>Synchronizing</source>
        <translation>Synchronizace</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="453"/>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
        <source>Out of sync</source>
        <translation>Nesesynchronizováno</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
        <source>Dir/item</source>
        <translation>Adr./položka</translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
        <source>Progress</source>
        <translation>Postup</translation>
    </message>
</context>
</TS>

==> syncthingtray_1.2.2.orig.tar.gz: syncthingtray-1.2.2/model/translations/syncthingmodel_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="217"/>
        <source>Misc. notifications</source>
        <translation>Různá oznámení</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="218"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="219"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="220"/>
        <source>Idle</source>
        <translation>Nečinné</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="221"/>
        <source>Scanning</source>
        <translation>Skenuje</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="222"/>
        <source>Synchronizing</source>
        <translation>Synchronizuje</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="223"/>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="224"/>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="85"/>
        <location filename="../syncthingdevicemodel.cpp" line="115"/>
        <source>ID</source>
        <translation>Identifikátor</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="87"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="117"/>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="119"/>
        <source>Last seen</source>
        <translation>Naposledy spatřeno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="121"/>
        <source>Compression</source>
        <translation>Komprese</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="123"/>
        <source>Certificate</source>
        <translation>Certifikát</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="125"/>
        <source>Introducer</source>
        <translation>Zavaděč</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="127"/>
        <source>Incoming traffic</source>
        <translation>Příchozí provoz</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="129"/>
        <source>Outgoing traffic</source>
        <translation>Odchozí provoz</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="131"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="151"/>
        <source>unknown or own device</source>
        <translation>neznámé nebo vlastní zařízení</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="156"/>
        <source>none</source>
        <translation>žádné</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="158"/>
        <source>yes</source>
        <translation>ano</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="158"/>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="368"/>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="372"/>
        <source>Unknown status</source>
        <translation>Neznámý stav</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="374"/>
        <source>Own device</source>
        <translation>Vlastní zařízení</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="376"/>
        <source>Idle</source>
        <translation>Nečinné</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="378"/>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="383"/>
        <source>Synchronizing</source>
        <translation>Synchronizuje se</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="380"/>
        <source>Synchronizing (%1 %, %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="385"/>
        <source>Out of sync</source>
        <translation>Nesesynchronizováno</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="387"/>
        <source>Rejected</source>
        <translation>Odmítnuto</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
        <source>ID</source>
        <translation>Identifikátor</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
        <source>Path</source>
        <translation>Popis umístění</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Rescan interval</source>
        <translation>Interval skenování</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Last scan</source>
        <translation>Poslední sken</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Last file</source>
        <translation>Poslední soubor</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Errors</source>
        <translation>Chyby</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
        <source>not shared</source>
        <translation>nesdíleno</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
        <source>unknown</source>
        <translation>neznámé</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 and %2 item(s) out of sync</source>
        <translation>
            <numerusform>%1 a %2 položka nesesynchronizována</numerusform>
            <numerusform>%1 a %2 položky nesesynchronizovány</numerusform>
            <numerusform>%1 a %2 položek nesesynchronizováno</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <source>none</source>
        <translation>žádno</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <source>%1 item(s) out of sync</source>
        <translation>
            <numerusform>%1 položka nesesynchronizována</numerusform>
            <numerusform>%1 položky nesesyncrhonizovány</numerusform>
            <numerusform>%1 položek nesesyncrhonizováno</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
        <source>Deleted at %1</source>
        <translation>Smazáno na %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
        <source>Updated at %1</source>
        <translation>Aktualizováno na %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
        <source>Click for details</source>
        <translation>Pro podrobnosti klikněte</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
        <source>Failed items</source>
        <translation>Nezdařené položky</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="466"/>
        <source>Unknown status</source>
        <translation>Neznámý stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
        <source>Idle</source>
        <translation>Nečinné</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
        <source>Unshared</source>
        <translation>Nesdíleno</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>Global status</source>
        <translation>Globální stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Local status</source>
        <translation>Místní stav</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Shared with</source>
        <translation>Sdíleno s</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
        <source>Waiting to scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
        <source>Scanning (%1 %, %2)</source>
        <translation>Skenování (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
        <source>Scanning (%1 %)</source>
        <translation>Skenování (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
        <source>Scanning</source>
        <translation>Skenování</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="480"/>
        <source>Waiting to sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="482"/>
        <source>Preparing to sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing (%1 %)</source>
        <translation>Synchronizace (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing</source>
        <translation>Synchronizace</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="459"/>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="486"/>
        <source>Cleaning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="488"/>
        <source>Waiting to clean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="490"/>
        <source>Out of sync</source>
        <translation>Nesesynchronizováno</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
        <source>Dir/item</source>
        <translation>Adr./položka</translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
        <source>Progress</source>
        <translation>Postup</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingRecentChangesModel</name>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="77"/>
        <source>Path</source>
        <translation type="unfinished">Popis umístění</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Locally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Remotely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingStatusComputionModel</name>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
        <source>Local dir is scanning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
        <source>Local dir is synchronizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
        <source>Remote dir has outstanding progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
        <source>A device is paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
        <source>Local dir is out of sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
        <source>Unread notification present</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
